@@ -100,7 +100,7 @@ class UiController:
         
         # Tree Controller
         tree = self.manager_ui.tree_widget
-        self.tree_controller = TreeController(tree, self.manager_ui, self.controller.log)
+        self.tree_controller = TreeController(tree, self.manager_ui, self.controller)
 
         # Hide public link elements (not used yet)
         self.manager_ui.public_link_line_edit.hide()
@@ -464,10 +464,11 @@ class UiController:
 
 class TreeController:
 
-    def __init__(self, tree_widget, controls_ui, logger):
+    def __init__(self, tree_widget, controls_ui, controller):
         self.tree = tree_widget
         self.controls_ui = controls_ui
-        self.log = logger
+        self.controller = controller
+        self.log = controller.log
 
         self.root_folder = None
         self.last_clicked = None
